---
images:
  - /images/uploads/Django11.jpg
title: Перенаправление страниц Django
slug: перенаправление-страниц-django
date: 2019-09-04T00:00:00+03:00
categories:
  - Программирование
  - Веб-разработка
  - Django
tags:
  - Курс молодого бойца Django
draft: false
---

![](/images/uploads/Django11.jpg)

Перенаправление страниц необходимо по многим причинам в веб-приложениях. Возможно, вы захотите перенаправить пользователя
на другую страницу, когда происходит определенное действие, или в основном в случае ошибки. Например, когда пользователь
входит на ваш сайт, его часто перенаправляют либо на главную домашнюю страницу, либо на его личную панель инструментов.
В Django перенаправление выполняется методом **redirect**.

Метод **redirect** принимает в качестве аргумента URL-адрес, на который вы хотите быть перенаправлены, представляющий
собой строку.

Файл **myapp/views.py** пока выглядит следующим образом:

```
def hello(request):
    today = datetime.datetime.now().date()
    daysOfWeek = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
    return render(request, "hello.html", {"today" : today, "days_of_week" : daysOfWeek})

def viewArticle(request, articleId):
    """ A view that display an article based on his ID"""
    text = "Displaying article Number : %s" %articleId
    return HttpResponse(text)

def viewArticles(request, year, month):
    text = "Displaying articles of : %s/%s"%(year, month)
    return HttpResponse(text)
```

Давайте изменим представление hello для перенаправления на **djangoproject.com**, а **viewArticle** для перенаправления
на наш внутренний адрес **/myapp/article**. Файл **myapp/view.py** изменится и станет выглядеть следующим образом:

```
from django.shortcuts import render, redirect
from django.http import HttpResponse
import datetime

# Create your views here.
def hello(request):
    today = datetime.datetime.now().date()
    daysOfWeek = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
    return redirect("https://www.djangoproject.com")

def viewArticle(request, articleId):
    """ A view that display an article based on his ID"""
    text = "Displaying article Number : %s" %articleId
    return redirect(viewArticles, year = "2045", month = "02")

def viewArticles(request, year, month):
    text = "Displaying articles of : %s/%s"%(year, month)
    return HttpResponse(text)
```

В приведенном выше примере сначала мы импортировали функцию для перенаправления из **django.shortcuts**. Для перенаправления
на официальный сайт Django мы просто передали полный URL-адрес методу **redirect** в виде строки, а для второго примера
(представление **viewArticle**) метод перенаправления принимает имя представления и его параметры в качестве аргументов.

Получив доступ к **/myapp/hello**, вы увидите следующее:

![](https://i.imgur.com/34Gdf71.png)

А доступ к **/myapp/article/42**, даст вам следующий результат:

![](https://i.imgur.com/InwKXC6.png)

Также можно указать, является ли перенаправление временным или постоянным, добавив параметр **constant = True**.
Пользователь не увидит никакой разницы, но это детали, которые поисковые системы учитывают при ранжировании вашего сайта.

Также помните, что мы определили параметр **name** в нашем **urls.py** при сопоставлении URL-адреса:

```
url(r'^articles/(?P\d{2})/(?P\d{4})/', 'viewArticles', name = 'articles'),
```

Это имя (в данном случае **articles**) может использоваться в качестве аргумента для метода **redirect**, тогда наше
перенаправление **viewArticle** может быть изменено с:

```
def viewArticle(request, articleId):
    """ A view that display an article based on his ID"""
    text = "Displaying article Number : %s" %articleId
    return redirect(viewArticles, year = "2045", month = "02")
```

На:

```
def viewArticle(request, articleId):
    """ A view that display an article based on his ID"""
    text = "Displaying article Number : %s" %articleId
    return redirect(articles, year = "2045", month = "02")
```

**Примечание.** Существует также функция для генерации URL (обратный метод **django.core.urlresolvers.reverse**), она
используется так же как перенаправление. Эта функция возвращает не объект **HttpResponseRedirect**, а просто строку,
содержащую URL-адрес представления, скомпилированный с любым переданным аргументом.

Источник: [Django — Page Redirection](https://www.tutorialspoint.com/django/django_page_redirection.htm)
