---
images:
  - /images/uploads/docker4.jpg
title: Образы Docker
slug: образы-docker
date: 2019-07-30T00:00:00+03:00
categories:
  - Docker
tags:
  - Курс молодого бойца Docker
draft: false
---

![](/images/uploads/docker4.jpg)

В Docker всё основано на образах. Образ представляет собой объединение файловой системы и параметров. Давайте рассмотрим
пример следующей команды Docker:

```
docker run hello-world
```

- команда **docker** – это специальная команда, которая сообщает программе Docker, находящейся в ОС, о том, что нужно что-либо сделать.
- команда **run** используется для упоминания того, что мы хотим создать экземпляр образа, который затем будет назван контейнером.
- “hello world” представляет собой образ, из которого будет создан контейнер.

Теперь обратим внимание на то, как мы можем использовать образ CentOS, доступный для скачивания в Docker Hub, для запуска
CentOS на нашем Ubuntu сервере. Сделать это можно посредством ввода следующей команды:

```
sudo docker run -it centos /bin/bash
```

Разберём вызов команды **sudo**:

- **sudo** — используется для обеспечения выполнения команды с root-правами.
- **centos** — это имя образа, который мы хотим загрузить с Docker Hub и установить на наш Ubuntu сервер.
- **-it** — используется для того, чтобы работать в интерактивном режиме.
- **/bin/bash** — используется для запуска оболочки bash после запуска CentOS.

## Отображение образов Docker

Чтобы вывести список образов Docker, установленных в вашей системе, воспользуйтесь следующей командой:

```
docker images
```

Вывод будет содержать список всех образов Docker.

### Пример

Введём следующий запрос:

```
sudo docker images
```

Пример вывода:

![](https://i.imgur.com/mAoNb6Z.jpg)

Из вывода видно, что на сервере установлены три образа: **centos**, **newcentos** и **jenkins**. Каждый образ обладает
набором характеристик:

- **TAG** — отвечает за логическую маркировку образов.
- **IMAGE ID** — отвечает за уникальный идентификатор образа.
- **Created** — отвечает за количество дней с момента создания образа.
- **Virtual Size** — отвечает за размер образа.

## Загрузка образов Docker

Загрузить образы можно с Docker Hub, при помощи команды Docker **run** следующим образом:

```
docker run image
```

- **image** — это имя образа, которое используется для запуска контейнера.

Вывод выполнит команду в нужном контейнере.

### Пример

Следующая команда загрузит образ **centos**, если он ещё не загружен, и запустит операционную систему как контейнер:

```
sudo docker run centos
```

Пример вывода:

![](https://i.imgur.com/VO9qSeH.jpg)

Теперь вы увидите загруженный образ CentOS Docker. Если мы запустим команду Docker **images**, чтобы увидеть список
образов в системе, мы также сможем увидеть образ **centos**.

![](https://i.imgur.com/RirHdpk.jpg)

## Удаление образов Docker

Образ Docker может быть удалён из системы с помощью команды **docker rmi**. Детальнее рассмотрим данную команду:

```
docker rmi
```

Итак, данная команда необходима для удаления образов Docker, рассмотрим её применение на конкретном примере:

```
docker rmi ImageID
```

- **ImageID** — это идентификатор образа, который вы хотите удалить.

Вывод будет содержать ID удалённого образа:

![](https://i.imgur.com/AqSjMkA.jpg)

Рассмотрим ещё несколько команд Docker в картинках.

## docker images -q

Данная команда используется для возврата только идентификаторов образов:

```
docker images
```

- **q** — сообщает команде Docker о том, что нужно возвращать только идентификатор образа.

Выходные данные будут отображать только идентификаторы образов на хосте Docker.

### Пример

```
sudo docker images -q
```

Пример вывода:

![](https://i.imgur.com/IRC1Svu.jpg)

## docker inspect

Данная команда выводит информацию об образе или о контейнере.

```
docker inspect Repository
```

- **Repository** — это имя образа.

В выводе будет содержаться подробная информация об образе.

### Пример

```
sudo docker inspect jenkins
```

Пример вывода:

![](https://i.imgur.com/1oR3bLq.jpg)

Источник: [Docker Images](https://www.tutorialspoint.com/docker/docker_images.htm)
