---
images:
  - /images/uploads/docker17.jpg
title: Команды терминала Docker
slug: команды-терминала-docker
date: 2019-08-14T01:00:00+03:00
categories:
  - Docker
tags:
  - Курс молодого бойца Docker
draft: false
---

![](/images/uploads/docker17.jpg)

Docker имеет множество терминальных команд. Эти команды мы используем в **Dockerfile**, поэтому давайте рассмотрим
некоторые из них.

## Команда CMD

Данная команда используется для выполнения команды во время работы контейнера.

```
CMD command param1
```

- **command** — эта команда запускается при запуске контейнера.
- **param1** — это параметр, передаваемый команде.

Команда будет выполнена соответствующим образом.

### Пример

В нашем примере мы выведем сообщение **Hello World**, создадим образ, а также запустим из него контейнер.

**Шаг 1.** Первым делом соберём **Dockerfile** с помощью следующих команд:

```
FROM ubuntu
MAINTAINER demousr@gmail.com
CMD [“echo” , “hello world”]
```

Здесь **CMD** используется для вывода **hello world**.

![](https://i.imgur.com/5Wofn9G.jpg)

**Шаг 2.** Затем соберём образ с помощью команды Docker **build**.

![](https://i.imgur.com/UEb9u0K.jpg)

**Шаг 3.** Далее запустим контейнер из образа.

![](https://i.imgur.com/fWbaT2F.jpg)

## ENTRYPOINT

Эта команда может быть также использована для выполнения команды во время работы контейнера.

```
ENTRYPOINT command param1
```

- **command** — эта команда запускается при запуске контейнера.
- **param1** — это параметр, передаваемый команде.

Команда будет выполнена соответствующим образом.

### Пример

Чтобы подробнее ознакомиться с командой **ENTRYPOINT**, мы рассмотрим пример, в котором мы введём команду **echo** в наш
**Dockerfile**, создадим образ и запустим из него контейнер.

**Шаг 1.** Первым делом соберём **Dockerfile** с помощью следующих команд:

```
FROM ubuntu
MAINTAINER demousr@gmail.com
ENTRYPOINT [“echo”]
```

![](https://i.imgur.com/UA19hxR.jpg)

**Шаг 2.** Затем соберём образ с помощью команды Docker **build**.

![](https://i.imgur.com/dw9cB05.jpg)

**Шаг 3.** Далее запустите контейнер из образа.

![](https://i.imgur.com/FZhv7Bw.jpg)

## ENV

Данная команда используется для установки переменных среды в контейнере.

```
ENV key value
```

- **Key** — это ключ для переменной среды.
- **value** — это значение для переменной среды.

Команда будет выполнена соответствующим образом.

### Пример

В данном примере мы введём команду **echo** в наш **Dockerfile**, создадим образ и запустим из него контейнер.

**Шаг 1.** Первым делом соберём **Dockerfile** с помощью следующих команд:

```
FROM ubuntu
MAINTAINER demousr@gmail.com
ENV var1=Tutorial var2=point
```

![](https://i.imgur.com/gyabhHJ.jpg)

**Шаг 2.** Затем соберите образ с помощью команды Docker **build**.

![](https://i.imgur.com/R7HGOXI.jpg)

**Шаг 3.** Далее запустите контейнер из образа.

![](https://i.imgur.com/IBZFEGW.jpg)

**Шаг 4.** Наконец, выполните команду env, чтобы увидеть переменные среды.

![](https://i.imgur.com/nmZ5nnL.jpg)

## WORKDIR

Данная команда используется для установки рабочей директории контейнера.

```
WORKDIR dirname
```

- **dirname** — новая рабочая директория. Если директория изначально не существует, она будет создана автоматически.

Команда будет выполнена соответствующим образом.

### Пример

В данном примере мы введём команду **echo** в наш **Dockerfile**, создадим образ и запустим из него контейнер.

**Шаг 1.** Первым делом соберите **Dockerfile** с помощью следующих команд:

```
FROM ubuntu
MAINTAINER demousr@gmail.com
WORKDIR /newtemp
CMD pwd
```

![](https://i.imgur.com/dOvlFbp.jpg)

**Шаг 2.** Затем соберите образ с помощью команды Docker **build**.

![](https://i.imgur.com/Mx5N38r.jpg)

**Шаг 3.** Далее запустите контейнер из образа.

![](https://i.imgur.com/HS4WjoT.jpg)

Источник: [Docker — Instruction Commands](https://www.tutorialspoint.com/docker/docker_instruction_commands.htm)
